@@ -10,16 +10,13 @@ class TraktAuthCommand(Command):
     """
 
     def handle(self):
-        from trakt_scrobbler import trakt_interface as ti
-        from datetime import date
+        from trakt_scrobbler.trakt_interface import trakt_auth
 
         if self.option("force"):
             self.line("Forcing trakt authentication")
-            ti.TRAKT_TOKEN_PATH.unlink(missing_ok=True)
-        if not ti.get_access_token():
+            trakt_auth.clear_token()
+        if not trakt_auth.get_access_token():
             self.line("Failed to retrieve trakt token.", "error")
             return 1
-        expiry = date.fromtimestamp(
-            ti.token_data["created_at"] + ti.token_data["expires_in"]
-        )
-        self.line(f"Token valid until: {expiry}")
+        expiry_date = trakt_auth.token_expires_at().date()
+        self.line(f"Token valid until {expiry_date:%x}")
